import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { isOverlayActiveSelector } from '@/redux/overlayBioEntity/overlayBioEntity.selector';
import { removeOverlayBioEntityForGivenOverlay } from '@/redux/overlayBioEntity/overlayBioEntity.slice';
import { getOverlayBioEntityForAllModels } from '@/redux/overlayBioEntity/overlayBioEntity.thunk';
import { useEmptyBackground } from './useEmptyBackground';

type UseOverlay = {
  toggleOverlay: () => void;
  isOverlayActive: boolean;
};

export const useOverlay = (overlayId: number): UseOverlay => {
  const dispatch = useAppDispatch();
  const isOverlayActive = useAppSelector(state => isOverlayActiveSelector(state, overlayId));
  const { setBackgroundtoEmptyIfAvailable } = useEmptyBackground();

  const toggleOverlay = (): void => {
    if (isOverlayActive) {
      dispatch(removeOverlayBioEntityForGivenOverlay({ overlayId }));
    } else {
      setBackgroundtoEmptyIfAvailable();
      dispatch(getOverlayBioEntityForAllModels({ overlayId }));
    }
  };

  return { toggleOverlay, isOverlayActive };
};
