import type { GetHex3ColorGradientColorWithAlpha } from '@/hooks/useTriColorLerp';
import { OverlayBioEntityRender } from '@/types/OLrendering';
import { UsePointToProjectionResult } from '@/utils/map/usePointToProjection';
import type Feature from 'ol/Feature';
import type Polygon from 'ol/geom/Polygon';
import { OverlayOrder } from '@/redux/overlayBioEntity/overlayBioEntity.utils';
import { ZERO } from '@/constants/common';
import { createOverlayGeometryFeature } from './createOverlayGeometryFeature';
import { getColorByAvailableProperties } from './getColorByAvailableProperties';
import { getPolygonLatitudeCoordinates } from './getPolygonLatitudeCoordinates';

type GetOverlayFeaturesProps = {
  bioEntities: OverlayBioEntityRender[];
  pointToProjection: UsePointToProjectionResult;
  getHex3ColorGradientColorWithAlpha: GetHex3ColorGradientColorWithAlpha;
  defaultColor: string;
  overlaysOrder: OverlayOrder[];
};

export const getOverlayFeatures = ({
  bioEntities,
  pointToProjection,
  getHex3ColorGradientColorWithAlpha,
  defaultColor,
  overlaysOrder,
}: GetOverlayFeaturesProps): Feature<Polygon>[] =>
  bioEntities.map(entity => {
    /**
     * Depending on number of active overlays
     * it's required to calculate xMin and xMax coordinates of the polygon
     * so "entity" might be devided equali between active overlays
     */
    const { xMin, xMax } = getPolygonLatitudeCoordinates({
      width: entity.width,
      nOverlays: overlaysOrder.length,
      xMin: entity.x1,
      overlayIndexBasedOnOrder:
        overlaysOrder.find(({ id }) => id === entity.overlayId)?.index || ZERO,
    });

    return createOverlayGeometryFeature(
      [
        ...pointToProjection({ x: xMin, y: entity.y1 }),
        ...pointToProjection({ x: xMax, y: entity.y2 }),
      ],
      getColorByAvailableProperties(entity, getHex3ColorGradientColorWithAlpha, defaultColor),
    );
  });
